==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/igr-form.js <==
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrFormDataEventArgs } from "./igr-form-data-event-args";
import { IgrVoidEventArgs } from "./igr-void-event-args";
import { Form } from "./Form";
import { TypeRegistrar } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { IgcFormComponent, defineComponents } from "igniteui-webcomponents";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
/**
 * The form is a component used to collect user input from
 * interactive controls.
*/
export class IgrForm extends React.Component {
    createImplementation() {
        return new Form();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    constructor(props) {
        super(props);
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._submit = null;
        this._submit_wrapped = null;
        this._reset = null;
        this._reset_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcFormComponent);
        this._implementation = this.createImplementation();
        this._portalManager = new PortalManager("templates", () => this.setState({}));
        this._renderer = new ReactRenderer(this._implementation.nativeElement, document, false, null, this._portalManager);
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let div = React.createElement("igc-form", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * Specifies if form data validation should be skipped on submit.
    */
    get novalidate() {
        return this.i.e;
    }
    set novalidate(v) {
        this.i.e = ensureBool(v);
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Form");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
    /**
     * Submits the form.
    
    */
    performSubmit() {
        let iv = this.i.f();
        return (iv);
    }
    /**
     * Resets the form.
    
    */
    performReset() {
        this.i.j();
    }
    /**
     * Checks for validity of the form.
    
    */
    reportValidity() {
        let iv = this.i.g();
        return (iv);
    }
    get submit() {
        return this._submit;
    }
    set submit(ev) {
        if (this._submit_wrapped !== null) {
            this.i.submit = delegateRemove(this.i.submit, this._submit_wrapped);
            this._submit_wrapped = null;
            this._submit = null;
        }
        this._submit = ev;
        this._submit_wrapped = (o, e) => {
            let outerArgs = new IgrFormDataEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSubmit) {
                this.beforeSubmit(this, outerArgs);
            }
            if (this._submit) {
                this._submit(this, outerArgs);
            }
        };
        this.i.submit = delegateCombine(this.i.submit, this._submit_wrapped);
        if (this.i.submitChanged) {
            this.i.submitChanged();
        }
        ;
    }
    get reset() {
        return this._reset;
    }
    set reset(ev) {
        if (this._reset_wrapped !== null) {
            this.i.reset = delegateRemove(this.i.reset, this._reset_wrapped);
            this._reset_wrapped = null;
            this._reset = null;
        }
        this._reset = ev;
        this._reset_wrapped = (o, e) => {
            let outerArgs = new IgrVoidEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeReset) {
                this.beforeReset(this, outerArgs);
            }
            if (this._reset) {
                this._reset(this, outerArgs);
            }
        };
        this.i.reset = delegateCombine(this.i.reset, this._reset_wrapped);
        if (this.i.resetChanged) {
            this.i.resetChanged();
        }
        ;
    }
}

==> igniteui-react-18.5.2-beta.0.tgz: package/esm2015/lib/igr-form.js <==
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrFormDataEventArgs } from "./igr-form-data-event-args";
import { IgrVoidEventArgs } from "./igr-void-event-args";
import { Form } from "./Form";
import { TypeRegistrar } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { IgcFormComponent, defineComponents } from "igniteui-webcomponents";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
export class IgrForm extends React.Component {
    createImplementation() {
        return new Form();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    constructor(props) {
        super(props);
        this.mounted = false;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._submit = null;
        this._submit_wrapped = null;
        this._reset = null;
        this._reset_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcFormComponent);
        this._implementation = this.createImplementation();
        this._portalManager = new PortalManager("templates", () => {
            if (this.mounted) {
                this.setState({});
            }
        });
        if (typeof window !== 'undefined' && typeof document !== 'undefined') {
            this._renderer = new ReactRenderer(this._implementation.nativeElement, document, false, null, this._portalManager);
        }
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let div = React.createElement("igc-form", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * Specifies if form data validation should be skipped on submit.
    */
    get novalidate() {
        return this.i.e;
    }
    set novalidate(v) {
        this.i.e = ensureBool(v);
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Form");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
    /**
     * Submits the form.
    
    */
    performSubmit() {
        let iv = this.i.f();
        return (iv);
    }
    /**
     * Resets the form.
    
    */
    performReset() {
        this.i.j();
    }
    /**
     * Checks for validity of the form.
    
    */
    reportValidity() {
        let iv = this.i.g();
        return (iv);
    }
    get submit() {
        return this._submit;
    }
    set submit(ev) {
        if (this._submit_wrapped !== null) {
            this.i.submit = delegateRemove(this.i.submit, this._submit_wrapped);
            this._submit_wrapped = null;
            this._submit = null;
        }
        this._submit = ev;
        this._submit_wrapped = (o, e) => {
            let outerArgs = new IgrFormDataEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSubmit) {
                this.beforeSubmit(this, outerArgs);
            }
            if (this._submit) {
                this._submit(this, outerArgs);
            }
        };
        this.i.submit = delegateCombine(this.i.submit, this._submit_wrapped);
        if (this.i.submitChanged) {
            this.i.submitChanged();
        }
        ;
    }
    get reset() {
        return this._reset;
    }
    set reset(ev) {
        if (this._reset_wrapped !== null) {
            this.i.reset = delegateRemove(this.i.reset, this._reset_wrapped);
            this._reset_wrapped = null;
            this._reset = null;
        }
        this._reset = ev;
        this._reset_wrapped = (o, e) => {
            let outerArgs = new IgrVoidEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeReset) {
                this.beforeReset(this, outerArgs);
            }
            if (this._reset) {
                this._reset(this, outerArgs);
            }
        };
        this.i.reset = delegateCombine(this.i.reset, this._reset_wrapped);
        if (this.i.resetChanged) {
            this.i.resetChanged();
        }
        ;
    }
}
